use log::LevelFilter;
use serde::{Deserialize, Serialize};

#[derive(Debug, Serialize, Deserialize, Clone)]
pub enum LogLevel {
    #[serde(rename = "trace")]
    Trace,
    #[serde(rename = "debug")]
    Debug,
    #[serde(rename = "Info")]
    Info,
    #[serde(rename = "warn")]
    Warn,
    #[serde(rename = "error")]
    Error,
}

impl Into<LevelFilter> for LogLevel {
    fn into(self) -> LevelFilter {
        match self {
            LogLevel::Trace => LevelFilter::Trace,
            LogLevel::Debug => LevelFilter::Debug,
            LogLevel::Info => LevelFilter::Info,
            LogLevel::Warn => LevelFilter::Warn,
            LogLevel::Error => LevelFilter::Error,
        }
    }
}

#[derive(Debug, Serialize, Deserialize, Clone)]
pub struct LogConfig {
    pub stdout_level: LogLevel,
    pub file_level: LogLevel,
}

impl Default for LogConfig {
    fn default() -> Self {
        Self {
            // Linter says it's not fine but it is.
            #[cfg(not(debug_assertions))]
            stdout_level: LogLevel::Info,
            #[cfg(debug_assertions)]
            stdout_level: LogLevel::Trace,

            file_level: LogLevel::Trace,
        }
    }
}
