use log::LogConfig;
use node::NodeConfig;
use serde::{Deserialize, Serialize};
use std::{fs, io};
use ::log::trace;

pub mod log;
pub mod node;

#[derive(Debug, Serialize, Deserialize, Default, Clone)]
#[serde(default)]
pub struct Config {
    pub node: NodeConfig,
    pub log: LogConfig,
}

impl Config {
    pub fn from_path<S: Into<String>>(path: S) -> io::Result<Self> {
        let path = path.into().clone();
        trace!("importing config from {}...", path);
        let s = fs::read_to_string(path.clone())?;
        let c: Config = toml::from_str(s.as_str()).map_err(|_| {
            io::Error::new(
                io::ErrorKind::InvalidData,
                format!("{} has invalid data", path),
            )
        })?;
        Ok(c)
    }
}
